Learn R Programming

Ditwah (version 1.0.0)

realtime_waterlevel_kelani_ganga: Real-time water level data for Kelani river basin

Description

This dataset contains real-time rainfall and river water-level observations from hydrometric stations in the Kelani river basin. The data were obtained from dashboard by Hydrology and Disaster Management Division, Irrigation Department, Sri Lanka.

Usage

realtime_waterlevel_kelani_ganga

Arguments

Format

A data frame with the following 10 variables:

Date

Date of the observation

Time

Hour of the day

RiverBasin

Name of the river basin.

HydrometricStation

Name of the hydrometric (gauging) station.

Rainfall_mm

Rainfall recorded at the station (in millimetres).

RiverWaterLevel

Observed river water level.

RiverWaterLevel_Unit

Unit of measurement for the water level (e.g.,m, ft).

Alert_level

Official alert level corresponding to the observed water level.

Minor_Flood_Level

Threshold level that triggers a minor flood alert.

Major_Flood_level

Threshold level that triggers a major flood alert.